What’s new in release 2.1.0? — Aglyph 3.0.0 documentation

# What’s new in release 2.1.0?

- The Python 2.6 lifespan has ended and it is no longer actively supported in Aglyph. (Aglyph 2.1.0 will not run on Python 2.6 without patching)
- Aglyph now supports lifecycle methods, which may be declared at the context, template, and/or component level for the “after injection” and “before clear” lifecycle states.
- Aglyph now supports a form of component “inheritance” through `aglyph.component.Template` (XML `<template>`). Refer to Component inheritance using templates for examples.
- The `Aglyph context DTD` has been updated to support both lifecycle methods and templates.
- The `aglpyh.integration` package has been added to support integrating Aglyph with other projects. Aglyph 2.1.0 introduces CherryPy integration using the classes defined in `aglyph.integration.cherrypy`. Refer to Integrating Aglyph for examples.
- The caches defined in `aglyph.cache` are now implemented as Context Manager Types, and the public `lock` members have been deprecated.
- A “safe” representation is now used to log assembled objects, ensuring that possibly sensitive data is not logged.
- Deprecated classes and functions now issue `aglyph.AglyphDeprecationWarning`.